==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/Explode/ts/Explode_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>Dialog</name>
    <message>
        <location filename="../ExplodeDialog.ui" line="+14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Ellipses</source>
        <translation>Ellipsen</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Splines</source>
        <translation>Splines</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Dimensions</source>
        <translation>Bemassungen</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Hatches</source>
        <translation>Schraffuren</translation>
    </message>
    <message>
        <location line="-77"/>
        <source>Arcs and Circles</source>
        <translation>Bögen und Kreise</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into line segments (fixed length)</source>
        <translation>in Liniensegmente (fixe Länge)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>into line segments (fixed angle)</source>
        <translation>in Liniensegmente (fixer Winkel)</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>into polyline with arc segments</source>
        <translation>in Polylinien mit Bogensegmenten</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+16"/>
        <source>into polyline with line segments</source>
        <translation>in Polylinien mit Liniensegmenten</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>into lines, solids and texts</source>
        <translation>in Linien, Füllungen und Texte</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>into lines</source>
        <translation>in Linien</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Blocks</source>
        <translation>Blöcke</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into entities</source>
        <translation>in Objekte</translation>
    </message>
</context>
<context>
    <name>Explode</name>
    <message>
        <location filename="../ExplodeInit.js" line="+2"/>
        <source>&amp;Explode</source>
        <translation>&amp;Aufbrechen</translation>
    </message>
    <message>
        <location filename="../Explode.js" line="+30"/>
        <source>Modify</source>
        <translation>Modifizieren</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Explode</source>
        <translation>Aufbrechen</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+133"/>
        <source>Spline segments:</source>
        <translation>Splinesegmente:</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Ellipse segments (per full ellipse):</source>
        <translation>Ellipsensegmente (Vollellipse):</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Spline approximation tolerance:</source>
        <translation>Spline Toleranz:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/Explode/ts/Explode_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>Dialog</name>
    <message>
        <location filename="../ExplodeDialog.ui" line="+14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Ellipses</source>
        <translation>Ellipsen</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Splines</source>
        <translation>Splines</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Dimensions</source>
        <translation>Bemassungen</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Hatches</source>
        <translation>Schraffuren</translation>
    </message>
    <message>
        <location line="-77"/>
        <source>Arcs and Circles</source>
        <translation>Bögen und Kreise</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into line segments (fixed length)</source>
        <translation>in Liniensegmente (fixe Länge)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>into line segments (fixed angle)</source>
        <translation>in Liniensegmente (fixer Winkel)</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>into polyline with arc segments</source>
        <translation>in Polylinien mit Bogensegmenten</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+16"/>
        <source>into polyline with line segments</source>
        <translation>in Polylinien mit Liniensegmenten</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>into lines, solids and texts</source>
        <translation>in Linien, Füllungen und Texte</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>into lines</source>
        <translation>in Linien</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Blocks</source>
        <translation>Blöcke</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into entities</source>
        <translation>in Objekte</translation>
    </message>
</context>
<context>
    <name>Explode</name>
    <message>
        <location filename="../ExplodeInit.js" line="+2"/>
        <source>&amp;Explode</source>
        <translation>&amp;Aufbrechen</translation>
    </message>
    <message>
        <location filename="../Explode.js" line="+30"/>
        <source>Modify</source>
        <translation>Modifizieren</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Explode</source>
        <translation>Aufbrechen</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+197"/>
        <source>Explode text glyphs to polylines</source>
        <translation>Textumrisse aufbrechen in Polylinien</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Spline segments:</source>
        <translation>Splinesegmente:</translation>
    </message>
    <message>
        <location line="-27"/>
        <source>Ellipse segments (per full ellipse):</source>
        <translation>Ellipsensegmente (Vollellipse):</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Explode splines to polylines with line segments</source>
        <translation>Splines aufbrechen in Polylinien mit Liniensegmenten</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Explode multiline texts into multiple simple text blocks</source>
        <translation>Mehrzeilige Texte in mehrere einfache Texte aufbrechen</translation>
    </message>
    <message>
        <location line="-31"/>
        <source>Spline approximation tolerance:</source>
        <translation>Spline Toleranz:</translation>
    </message>
</context>
</TS>
